summaryrefslogtreecommitdiffstats
path: root/kfile-plugins/torrent/blist.h
diff options
context:
space:
mode:
Diffstat (limited to 'kfile-plugins/torrent/blist.h')
-rw-r--r--kfile-plugins/torrent/blist.h16
1 files changed, 8 insertions, 8 deletions
diff --git a/kfile-plugins/torrent/blist.h b/kfile-plugins/torrent/blist.h
index a00cca87..4085ec39 100644
--- a/kfile-plugins/torrent/blist.h
+++ b/kfile-plugins/torrent/blist.h
@@ -19,13 +19,13 @@
#ifndef _BLIST_H
#define _BLIST_H
-#include <qvaluelist.h>
-#include <qcstring.h>
+#include <tqvaluelist.h>
+#include <tqcstring.h>
#include "bbase.h"
#include "bytetape.h"
-typedef QValueList<BBase *> BBaseVector;
-typedef QValueList<BBase *>::iterator BBaseVectorIterator;
+typedef TQValueList<BBase *> BBaseVector;
+typedef TQValueList<BBase *>::iterator BBaseVectorIterator;
// Predeclare the following classes
class BDict;
@@ -50,7 +50,7 @@ class BList : public BBase
* @param start the position in the buffer to start
* reading from
*/
- BList (QByteArray &dict, unsigned int start = 0);
+ BList (TQByteArray &dict, unsigned int start = 0);
/**
* Construct a BList from @p tape. Any changes made to
@@ -175,11 +175,11 @@ class BList : public BBase
/**
* Outputs the b-encoded representation of the object to the given
* QIODevice.
* @param device the QIODevice to write to
* @return true on a successful write, false otherwise
*/
- virtual bool writeToDevice (QIODevice &device);
+ virtual bool writeToDevice (TQIODevice &device);
private:
@@ -175,11 +175,11 @@ class BList : public BBase
/**
* Outputs the b-encoded representation of the object to the given
- * QIODevice.
- * @param device the QIODevice to write to
+ * TQIODevice.
+ * @param device the TQIODevice to write to
* @return true on a successful write, false otherwise
*/